#!/usr/bin/python3

'''
spot コマンドで出力した vmtx,vorg の情報から、features ファイル用の vmtx テーブルの情報を出力。

$ conv-vmtx.py <spot-vmtx> [<spot-vorg>]

spot-vmtx:
	以下のコマンドで出力したファイル。
	$ spot -t vmtx=8 FONTFILE > vmtx.txt

spot-vorg:
	省略でなし。
	以下のコマンドで出力したファイル。
	$ spot -t VORG FONTFILE > vorg.txt
'''

import sys
import re

if len(sys.argv) < 2:
	print('[Usage] ' + sys.argv[0] + ' <spot-vmtx> [<spot-vorg>]')

fname_vmtx = sys.argv[1]
fname_vorg = None

if len(sys.argv) >= 3:
	fname_vorg = sys.argv[2]

class Conv:
	def __init__(self):
		self.out = ''

	# vmtx 追加
	def add_vmtx(self,fname):
		f = open(fname, 'rt')
		lines = f.readlines()
		f.close()

		mo = re.compile(r'\[(.+?)\]\=(\d+),')

		for l in lines[1].split(' '):
			m = mo.match(l)
			if not m: continue

			name = m.group(1)
			w = int(m.group(2))
			
			if w != 1000:
				self.out += '  VertAdvanceY {0} {1};\n'.format(name, w)

	# 出力
	# VORG 追加
	def add_vorg(self,fname):
		f = open(fname, 'rt')
		lines = f.readlines()
		f.close()

		mo = re.compile(r'([^ ]+?)\s+[^ ]+?\s+\=\s+(\d+)$')

		for l in lines:
			l = l.strip()
			if not l: continue

			m = mo.match(l)
			if not m: continue

			name = m.group(1)
			pos = m.group(2)

			self.out += '  VertOriginY {0} {1};\n'.format(name, pos)

	def output(self):
		print('table vmtx {')
		print(self.out, end='')
		print('} vmtx;')
	
#-----

c = Conv()
c.add_vmtx(fname_vmtx)

if fname_vorg:
	c.add_vorg(fname_vorg)

c.output()
